==> kdeclarative_5.44.0.orig.tar.xz: kdeclarative-5.44.0/src/qmlcontrols/kcmcontrols/kcmcontrolsplugin.cpp <==
/*
    Copyright 2017 by Marco Martin <mart@kde.org>

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
    THE SOFTWARE.
*/

#include "kcmcontrolsplugin.h"

#include <QtQml>

#include <KQuickAddons/ConfigModule>


void KCMControlsPlugin::registerTypes(const char *uri)
{
    Q_ASSERT(uri == QByteArray("org.kde.kcm"));

    qmlRegisterUncreatableType<KQuickAddons::ConfigModule>("org.kde.kcm", 1, 0, "ConfigModule",
            QLatin1String("Do not create objects of type ConfigModule"));
}

==> kdeclarative-5.73.0.tar.xz: kdeclarative-5.73.0/src/qmlcontrols/kcmcontrols/kcmcontrolsplugin.cpp <==
/*
    Copyright 2017 by Marco Martin <mart@kde.org>

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
    THE SOFTWARE.
*/

#include "kcmcontrolsplugin.h"


#include <KQuickAddons/ConfigModule>
#include "settingstateproxy.h"
#include "settingstatebindingprivate.h"

void KCMControlsPlugin::registerTypes(const char *uri)
{
    Q_ASSERT(uri == QByteArray("org.kde.kcm"));

    qmlRegisterUncreatableType<KQuickAddons::ConfigModule>(uri, 1, 0, "ConfigModule",
            QLatin1String("Do not create objects of type ConfigModule"));
    qmlRegisterType<SettingStateProxy>(uri, 1, 3, "SettingStateProxy");
    qmlRegisterType<SettingStateBindingPrivate>("org.kde.kcm.private", 1, 3, "SettingStateBindingPrivate");
}
